# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.shortcuts import render
from .models import APILog

# Create your views here.


def apilogger(meta_data):
    """
    Create log for api call each user
    """
    try:
        apilog = APILog.objects.create(**meta_data)
    except Exception as e:
        return False
    else:
        return True



'''
# ++++++++++++++++++++++++++++++++++++++++++++++++++++++++
# File: __init__.py
# Project: <<projectname>>
# File Created: Monday, 29th October 2018 3:32:20 pm
#
# Author: Arif Dzikrullah
#         ardzix@hotmail.com>
#         http://ardz.xyz>
#
# Last Modified: Monday, 29th October 2018 3:32:20 pm
# Modified By: arifdzikrullah (ardzix@hotmail.com>)
#
# Crafted by Pro
# Copyright - <<year>> Ardz & Co, -
# ++++++++++++++++++++++++++++++++++++++++++++++++++++++++
'''
